package com.example.ueberwachungssystem;

import androidx.annotation.NonNull;
import androidx.appcompat.app.AppCompatActivity;
import androidx.camera.core.ExperimentalGetImage;
import androidx.camera.view.PreviewView;

import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.ImageView;
import android.widget.ToggleButton;

import com.example.ueberwachungssystem.Detection.Accelerometer;
import com.example.ueberwachungssystem.Detection.AudioRecorder;
import com.example.ueberwachungssystem.Detection.DetectionReport;
import com.example.ueberwachungssystem.Detection.Detector;
import com.example.ueberwachungssystem.Detection.MicrophoneDetector;
import com.example.ueberwachungssystem.Detection.VideoDetector;

@ExperimentalGetImage
public class MainActivity extends AppCompatActivity {

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);


        ImageView inputImageView = findViewById(R.id.inputImageView);
        ImageView outputImageView = findViewById(R.id.outputImageView);
        PreviewView previewView = findViewById(R.id.previewView);


        PermissionHandler permissionHandler = new PermissionHandler(this);


        permissionHandler.getPermissions();

        if (permissionHandler.hasPermissions()) {
            AudioRecorder audioRecorder = new AudioRecorder(this);

            VideoDetector vd = new VideoDetector(this);
            //vd.debugProcessing(inputImageView, outputImageView);
            vd.setOnDetectionListener(new Detector.OnDetectionListener() {
                @Override
                public void onDetection(@NonNull DetectionReport detectionReport) {
                    Log.d("onDetection", detectionReport.toString());
                }
            });

            MicrophoneDetector microphoneDetector = new MicrophoneDetector(this);
            microphoneDetector.setOnDetectionListener(new Detector.OnDetectionListener() {
                @Override
                public void onDetection(@NonNull DetectionReport detectionReport) {
                    Log.d("onDetection", detectionReport.toString());
                }
            });

            Accelerometer accelerometer = new Accelerometer(this);
            accelerometer.getSensor();
            accelerometer.setOnDetectionListener(new Detector.OnDetectionListener() {
                @Override
                public void onDetection(@NonNull DetectionReport detectionReport) {
                    Log.d("onDetection", detectionReport.toString());
                }
            });


            ToggleButton toggleButton = findViewById(R.id.toggleButton);
            toggleButton.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    if (toggleButton.isChecked())
                    {
                        //vd.startDetection();
                        //vd.stopDetection();
                        vd.startDetection();
                        microphoneDetector.startDetection();
                        accelerometer.startDetection();

                        vd.startRecording();
                        audioRecorder.startRecording();
                    }
                    else {
                        //vd.stopDetection();
                        vd.stopRecording();
                        audioRecorder.stopRecording();
                    }
                }
            });







        }

    }
}